@@ -13,6 +13,7 @@ class Undefined(object):
         return False
 Undefined = Undefined() # singleton
 
+
 class Variable(object):
     """variable object for MakeItSo templates"""
     
@@ -125,6 +126,14 @@ class MakeItSoTemplate(ContentTemplate):
             assert os.path.exists(path), "%s does not exist" % path
             self._templates.append(path)
 
+    @classmethod
+    def get_description(cls):
+        if hasattr(cls, 'description'):
+            if cls.description:
+                return cls.description
+        if hasattr(cls, '__doc__'):
+            return cls.__doc__
+
     def get_variables(self, **variables):
         # XXX could do this in the ctor
         vars = ContentTemplate.get_variables(self, **variables)
